==> map-0.28.jar: PolygonData.java <==
import java.awt.*;
import java.awt.geom.*;

/*
 * : 2003/12/11
 */

/**
 * ݥꥴɽ饹Ǥ
 * @author Kumano Tatsuo
 */
class PolygonData {
    /**
     * ʪο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_BUILDING = 3500; // ʪ
    /**
     * Ϥο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_GRAVEYARD = 6215; // 
    /**
     * ο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_LAKE = 6105; // 
    /**
     * ¾ξϤο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_OTHER = 6200; // ¾ξ
    /**
     * ԻԸο޼ʬॳɤɽǤ
     */    
    public static int CLASSIFICATION_PARK = 6242; // ԻԸ
    /**
     * Ŵƻߤο޼ʬॳɤɽǤ
     */    
    public static int CLASSIFICATION_RAILROAD = 6241; // Ŵƻ
    /**
     * ο޼ʬॳɤɽǤ
     */    
    public static int CLASSIFICATION_RIVER = 6201; // 
    /**
     * عϤο޼ʬॳɤɽǤ
     */    
    public static int CLASSIFICATION_SCHOOL = 6243; // ع
    /**
     * ԶĮ¼ο޼ʬॳɤɽǤ
     */    
    public static int CLASSIFICATION_SI_TYO = 1105; // ԶĮ¼
    /**
     * ҡο޼ʬॳɤɽǤ
     */    
    public static int CLASSIFICATION_TEMPLE = 6244; // ҡ
    /**
     * Įܤο޼ʬॳɤɽǤ
     */    
    public static int CLASSIFICATION_TYOME = 1106; // Į
    /**
     * ʿ޼ʬॳɤɽǤ
     */    
    public static int CLASSIFICATION_UNKNOWN = 0; // ʿ޼ʬॳ
    /**
     * ѴۤθʪɤɽǤ
     */    
    public static int TATEMONO_ART_MUSEUM = 3529; // Ѵ
    /**
     * ɽθʪɤɽǤ
     */    
    public static int TATEMONO_FIRE_STATION = 3516; // ɽ
    /**
     * ΰߤθʪɤɽǤ
     */    
    public static int TATEMONO_GYM = 3530; // ΰ
    /**
     * ±
     */    
    public static int TATEMONO_HOSPITAL = 3532; // ±
    /**
     * ձࡢݰθʪɤɽǤ
     */    
    public static int TATEMONO_KINDERGARTEN = 3525; // ձࡦݰ
    /**
     * ޽ۤθʪɤɽǤ
     */    
    public static int TATEMONO_LIBRARY = 3528; // ޽
    /**
     * ¾δθʪɤɽǤ
     */    
    public static int TATEMONO_OTHER = 3503; // ¾δ
    /**
     * ٻ߽ꡢɽнθʪɤɽǤ
     */    
    public static int TATEMONO_POLICE_BOX = 3515; // ٻ߽ꡦɽн
    /**
     * ٻθʪɤɽǤ
     */    
    public static int TATEMONO_POLICE_STATION = 3514; // ٻ
    /**
     * ͹ضɤθʪɤɽǤ
     */    
    public static int TATEMONO_POST_OFFICE = 3509; // ͹ض
    /**
     * Ʋ̱ۤθʪɤɽǤ
     */    
    public static int TATEMONO_PUBLIC_HALL = 3526; // Ʋ̱
    /**
     * ݷθʪɤɽǤ
     */    
    public static int TATEMONO_PUBLIC_HEALTH_CENTER = 3531; // ݷ
    /**
     * ԡ̶衢Į¼Ȥζ졢ٽڤӽĥθʪɤɽǤ
     */    
    public static int TATEMONO_PUBLIC_OFFICE = 3519; // ԡ̶衦Į¼ԻԤζ졢ٽꤪӽĥ
    /**
     * ӿݥ׾θʪɤɽǤ
     */    
    public static int TATEMONO_PUMP = 3556; // ӿݥ׾
    /**
     * عθʪɤɽǤ
     */    
    public static int TATEMONO_SCHOOL = 3524; // ع
    /**
     * ʪۤθʪɤɽǤ
     */    
    public static int TATEMONO_SIENCE_MUSEUM = 3527; // ʪ
    /**
     * ؼˤθʪɤɽǤ
     */    
    public static int TATEMONO_STATION = 3543; // ؼ
    /**
     * ʸʪɤɽǤ
     */    
    public static int TATEMONO_UNKNOWN = 0; // ʸʪ
    
    private Area area; // ɽΰʿ޳Ԥˤޤݥꥴ礷Ρ
    private String attribute; // °
    private double attributeX; // °褹 x ɸ
    private double attributeY; // °褹 y ɸ
    private int classificationCode; // ޼ʬॳ
    private Color fillColor; // ɤĤ֤
    private String polygonName; // ֹ
    private int tatemonoCode; // ʪ
    private Font tyomeFont; // ܤΥե
    private double x; // ɽ x ɸ
    private double y; // ɽ y ɸ
    
    /**
     * ݥꥴޤ
     * @param polygonName ݥꥴθֹ
     * @param area ݥꥴɽΰ
     * @param type ݥꥴμ
     * @param x ɽ x ɸ
     * @param y ɽ y ɸ
     */
    PolygonData(String polygonName, Area area, int type, double x, double y) {
        this.polygonName = polygonName;
        this.area = area;
        this.classificationCode = type;
        this.x = x;
        this.y = y;
    }
    
    /**
     * Υݥꥴɽΰޤ
     * @return ΰ
     */
    Area getArea() {
        return area;
    }
    
    /** °ޤ
     * @return °
     */
    String getAttribute() {
        return attribute;
    }
    
    /**
     * °褹 x ɸޤ
     * @return x ɸ
     */
    public double getAttributeX() {
        return attributeX;
    }
    
    /**
     * °褹 y ɸޤ
     * @return x ɸ
     */
    public double getAttributeY() {
        return attributeY;
    }
    
    /** ޼ʬॳɤޤ
     * @return ޼ʬॳ
     */
    int getClassificationCode() {
        return classificationCode;
    }
    
    /** ɤĤ֤ޤ
     * @return ɤĤ֤
     */
    public Color getFillColor() {
        return fillColor;
    }
    
    /** ֹޤ
     * @return ֹ
     */
    String getPolygonName() {
        return polygonName;
    }
    
    /** ʪɤޤ
     * @return ʪ
     */
    public int getTatemonoCode() {
        return tatemonoCode;
    }
    
    /** ܤΥեȤޤ
     * @return ܤΥե
     */
    Font getTyomeFont() {
        return tyomeFont;
    }
    
    /** ɽ x ɸޤ
     * @return ɽ x ɸ
     */
    double getX() {
        return x;
    }
    
    /** ɽ y ɸޤ
     * @return ɽ y ɸ
     */
    double getY() {
        return y;
    }
    
    /**
     * Υݥꥴɽΰꤷޤ
     * ʣοեե˴ޤޤݥꥴΤФ礷ΰꤷޤ
     * @param area ΰ
     */
    void setArea(Area area) {
        this.area = area;
    }
    
    /** °ꤷޤ
     * @param string °
     */
    void setAttribute(String string) {
        attribute = string;
    }
    
    /**
     * °褹ɸꤷޤ
     * @param x x ɸ
     * @param y y ɸ
     */
    public void setAttributeLocation(double x, double y) {
        attributeX = x;
        attributeY = y;
    }
    
    /** ɤĤ֤ꤷޤ
     * @param color ɤĤ֤
     */
    public void setFillColor(Color color) {
        fillColor = color;
    }
    
    /** ʪɤꤷޤ
     * @param i ʪ
     */
    public void setTatemonoCode(int i) {
        tatemonoCode = i;
    }
    
    /** ܤΥեȤꤷޤ
     * @param font ܤΥե
     */
    void setTyomeFont(Font font) {
        tyomeFont = font;
    }
    
    /** ɽ x ɸꤷޤ
     * @param d ɽ x ɸ
     */
    public void setX(double d) {
        x = d;
    }
    
    /** ɽ y ɸꤷޤ
     * @param d ɽ y ɸ
     */
    public void setY(double d) {
        y = d;
    }
    
    /**
     * Υ֥Ȥʸɽޤ
     * @return ʸɽ
     */    
    public String toString() {
        return "[Polygon " + polygonName + "(" + attribute + ")]";
    }
    
}

==> map-1.01.jar: PolygonData.java <==
import java.awt.*;
import java.awt.geom.*;


/*
 * : 2003/12/11
 */

/**
 * ݥꥴɽ饹Ǥ
 * @author Kumano Tatsuo
 */
class PolygonData {
    /**
     * ʪο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_BUILDING = 3500; // ʪ

    /**
     * Ϥο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_GRAVEYARD = 6215; // 

    /**
     * ο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_LAKE = 6105; // 

    /**
     * ¾ξϤο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_OTHER = 6200; // ¾ξ

    /**
     * ԻԸο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_PARK = 6242; // ԻԸ

    /**
     * Ŵƻߤο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_RAILROAD = 6241; // Ŵƻ

    /**
     * ο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_RIVER = 6201; // 

    /**
     * عϤο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_SCHOOL = 6243; // ع

    /**
     * ԶĮ¼ο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_SI_TYO = 1105; // ԶĮ¼

    /**
     * ҡο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_TEMPLE = 6244; // ҡ

    /**
     * Įܤο޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_TYOME = 1106; // Į

    /**
     * ʿ޼ʬॳɤɽǤ
     */
    public static int CLASSIFICATION_UNKNOWN = 0; // ʿ޼ʬॳ

    /**
     * ѴۤθʪɤɽǤ
     */
    public static int TATEMONO_ART_MUSEUM = 3529; // Ѵ

    /**
     * ɽθʪɤɽǤ
     */
    public static int TATEMONO_FIRE_STATION = 3516; // ɽ

    /**
     * ΰߤθʪɤɽǤ
     */
    public static int TATEMONO_GYM = 3530; // ΰ

    /**
     * ±
     */
    public static int TATEMONO_HOSPITAL = 3532; // ±

    /**
     * ձࡢݰθʪɤɽǤ
     */
    public static int TATEMONO_KINDERGARTEN = 3525; // ձࡦݰ

    /**
     * ޽ۤθʪɤɽǤ
     */
    public static int TATEMONO_LIBRARY = 3528; // ޽

    /**
     * ¾δθʪɤɽǤ
     */
    public static int TATEMONO_OTHER = 3503; // ¾δ

    /**
     * ٻ߽ꡢɽнθʪɤɽǤ
     */
    public static int TATEMONO_POLICE_BOX = 3515; // ٻ߽ꡦɽн

    /**
     * ٻθʪɤɽǤ
     */
    public static int TATEMONO_POLICE_STATION = 3514; // ٻ

    /**
     * ͹ضɤθʪɤɽǤ
     */
    public static int TATEMONO_POST_OFFICE = 3509; // ͹ض

    /**
     * Ʋ̱ۤθʪɤɽǤ
     */
    public static int TATEMONO_PUBLIC_HALL = 3526; // Ʋ̱

    /**
     * ݷθʪɤɽǤ
     */
    public static int TATEMONO_PUBLIC_HEALTH_CENTER = 3531; // ݷ

    /**
     * ԡ̶衢Į¼Ȥζ졢ٽڤӽĥθʪɤɽǤ
     */
    public static int TATEMONO_PUBLIC_OFFICE = 3519; // ԡ̶衦Į¼ԻԤζ졢ٽꤪӽĥ

    /**
     * ӿݥ׾θʪɤɽǤ
     */
    public static int TATEMONO_PUMP = 3556; // ӿݥ׾

    /**
     * عθʪɤɽǤ
     */
    public static int TATEMONO_SCHOOL = 3524; // ع

    /**
     * ʪۤθʪɤɽǤ
     */
    public static int TATEMONO_SIENCE_MUSEUM = 3527; // ʪ

    /**
     * ؼˤθʪɤɽǤ
     */
    public static int TATEMONO_STATION = 3543; // ؼ

    /**
     * ʸʪɤɽǤ
     */
    public static int TATEMONO_UNKNOWN = 0; // ʸʪ
    private Area area; // ɽΰʿ޳Ԥˤޤݥꥴ礷Ρ
    private String attribute; // °
    private double attributeX; // °褹 x ɸ
    private double attributeY; // °褹 y ɸ
    private int classificationCode; // ޼ʬॳ
    private Color fillColor; // ɤĤ֤
    private int tyomeColorIndex; // ܤɤʬȤ˲ܤȤ
    private String polygonName; // ֹ
    private int tatemonoCode; // ʪ
    private Font tyomeFont; // ܤΥե
    private double x; // ɽ x ɸ
    private double y; // ɽ y ɸ

    /**
     * ݥꥴޤ
     * @param polygonName ݥꥴθֹ
     * @param area ݥꥴɽΰ
     * @param type ݥꥴμ
     * @param x ɽ x ɸ
     * @param y ɽ y ɸ
     */
    PolygonData(String polygonName, Area area, int type, double x, double y) {
        this.polygonName = polygonName;
        this.area = area;
        this.classificationCode = type;
        this.x = x;
        this.y = y;
    }

    /**
     * ܤɤʬȤ˲ܤȤꤷޤ
         * @param index ܤȤ
         */
    public void setTyomeColorIndex(int index) {
        this.tyomeColorIndex = index;
    }

    /**
     * ܤɤʬȤ˲ܤȤޤ
         * @return ܤȤ
         */
    public int getTyomeColorIndex() {
        return tyomeColorIndex;
    }

    /**
     * Υݥꥴɽΰޤ
     * @return ΰ
     */
    Area getArea() {
        return area;
    }

    /** °ޤ
     * @return °
     */
    String getAttribute() {
        return attribute;
    }

    /**
     * °褹 x ɸޤ
     * @return x ɸ
     */
    public double getAttributeX() {
        return attributeX;
    }

    /**
     * °褹 y ɸޤ
     * @return x ɸ
     */
    public double getAttributeY() {
        return attributeY;
    }

    /** ޼ʬॳɤޤ
     * @return ޼ʬॳ
     */
    int getClassificationCode() {
        return classificationCode;
    }

    /** ɤĤ֤ޤ
     * @return ɤĤ֤
     */
    public Color getFillColor() {
        return fillColor;
    }

    /** ֹޤ
     * @return ֹ
     */
    String getPolygonName() {
        return polygonName;
    }

    /** ʪɤޤ
     * @return ʪ
     */
    public int getTatemonoCode() {
        return tatemonoCode;
    }

    /** ܤΥեȤޤ
     * @return ܤΥե
     */
    Font getTyomeFont() {
        return tyomeFont;
    }

    /** ɽ x ɸޤ
     * @return ɽ x ɸ
     */
    double getX() {
        return x;
    }

    /** ɽ y ɸޤ
     * @return ɽ y ɸ
     */
    double getY() {
        return y;
    }

    /**
     * Υݥꥴɽΰꤷޤ
     * ʣοեե˴ޤޤݥꥴΤФ礷ΰꤷޤ
     * @param area ΰ
     */
    void setArea(Area area) {
        this.area = area;
    }

    /** °ꤷޤ
     * @param string °
     */
    void setAttribute(String string) {
        attribute = string;
    }

    /**
     * °褹ɸꤷޤ
     * @param x x ɸ
     * @param y y ɸ
     */
    public void setAttributeLocation(double x, double y) {
        attributeX = x;
        attributeY = y;
    }

    /** ɤĤ֤ꤷޤ
     * @param color ɤĤ֤
     */
    public void setFillColor(Color color) {
        fillColor = color;
    }

    /** ʪɤꤷޤ
     * @param i ʪ
     */
    public void setTatemonoCode(int i) {
        tatemonoCode = i;
    }

    /** ܤΥեȤꤷޤ
     * @param font ܤΥե
     */
    void setTyomeFont(Font font) {
        tyomeFont = font;
    }

    /** ɽ x ɸꤷޤ
     * @param d ɽ x ɸ
     */
    public void setX(double d) {
        x = d;
    }

    /** ɽ y ɸꤷޤ
     * @param d ɽ y ɸ
     */
    public void setY(double d) {
        y = d;
    }

    /**
     * Υ֥Ȥʸɽޤ
     * @return ʸɽ
     */
    public String toString() {
        return "[Polygon " + polygonName + "(" + attribute + ")]";
    }
}
